@@ -5,19 +5,19 @@ use warnings;
 
 package Archive::BagIt::Plugin::Algorithm::MD5;
 
-use Moose;
+use Moo;
 use namespace::autoclean;
 
 with 'Archive::BagIt::Role::Algorithm';
 
-has 'plugin_name' => (
+has '+plugin_name' => (
     is => 'ro',
     default => 'Archive::BagIt::Plugin::Algorithm::MD5',
 );
 
-has 'name' => (
+has '+name' => (
     is      => 'ro',
-    isa     => 'Str',
+    #isa     => 'Str',
     default => 'md5',
 );
 
@@ -70,7 +70,15 @@ Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
 
 =head1 VERSION
 
-version 0.056
+version 0.057
+
+=head1 NAME
+
+Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
+
+=head1 VERSION
+
+version 0.057
 
 =head1 AVAILABILITY
 
@@ -99,4 +107,15 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Rob Schmidt <rjeschmi@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
