@@ -6,7 +6,7 @@ use warnings;
 
 package Archive::BagIt::Role::Algorithm;
 
-use Moose::Role;
+use Moo::Role;
 with 'Archive::BagIt::Role::Plugin';
 
 has 'name' => (
@@ -32,7 +32,7 @@ sub register_plugin {
     $self->bagit->algos( {$self->name => $self });
     return 1;
 }
-no Moose;
+no Moo;
 1;
 
 __END__
@@ -47,7 +47,15 @@ Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing
 
 =head1 VERSION
 
-version 0.056
+version 0.057
+
+=head1 NAME
+
+Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing algorithm
+
+=head1 VERSION
+
+version 0.057
 
 =head1 AVAILABILITY
 
@@ -76,4 +84,15 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Rob Schmidt <rjeschmi@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
