@@ -2,14 +2,14 @@ use strict;
 use warnings;
 package Archive::BagIt::Role::Manifest;
 
-use Moose::Role;
+use Moo::Role;
 with 'Archive::BagIt::Role::Plugin';
 
 use namespace::autoclean;
 
 has 'algorithm' => (
     is => 'rw',
-    isa=>'HashRef',
+    #isa=>'HashRef',
 );
 
 sub BUILD {}
@@ -70,7 +70,7 @@ sub create_tagmanifest {
     return 1;
 }
 
-no Moose;
+no Moo;
 1;
 
 __END__
@@ -85,7 +85,15 @@ Archive::BagIt::Role::Manifest
 
 =head1 VERSION
 
-version 0.056
+version 0.057
+
+=head1 NAME
+
+Archive::BagIt::Role::Manifest
+
+=head1 VERSION
+
+version 0.057
 
 =head1 AVAILABILITY
 
@@ -114,4 +122,15 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Rob Schmidt <rjeschmi@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
