@@ -2,19 +2,19 @@ use strict;
 use warnings;
 package Archive::BagIt::Role::Plugin;
 
-use Moose::Role;
+use Moo::Role;
 
 use namespace::autoclean;
 
 has plugin_name => (
   is  => 'ro',
-  isa => 'Str',
+  #isa => 'Str',
   default => __PACKAGE__,
 );
 
 has bagit => (
   is  => 'ro',
-  isa => 'Archive::BagIt::Base',
+  #isa => 'Archive::BagIt::Base',
   required => 1,
   weak_ref => 1,
 );
@@ -25,7 +25,7 @@ sub BUILD {
     $self->bagit->plugins( { $plugin_name => $self });
     return 1;
 }
-no Moose;
+no Moo;
 1;
 
 __END__
@@ -40,7 +40,15 @@ Archive::BagIt::Role::Plugin
 
 =head1 VERSION
 
-version 0.056
+version 0.057
+
+=head1 NAME
+
+Archive::BagIt::Role::Plugin
+
+=head1 VERSION
+
+version 0.057
 
 =head1 AVAILABILITY
 
@@ -69,4 +77,15 @@ This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Rob Schmidt <rjeschmi@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
